OGC API - Records - Part 1: Core

- Capabilities
  - getlanding page
- Conformance
  - getinformation about specifications that this API conforms to
- Collections
  - getthe record collections
- Collection
  - getdescribe the record collection with id `catalogId`
- Sortables
  - getget the list of sortable properties
- Records
  - getfetch records
- Record
  - getfetch a single record

API docs by Redocly

# OGC API - Records - Part 1: Core (1.0.0)

Download OpenAPI specification:

CubeWerx Inc.: pvretano@cubewerx.com URL: https://www.cubewerx.com License: CC-BY 4.0 license

This is a sample OpenAPI definition that conforms to the conformance classes "Core", "GeoJSON", "HTML" and "OpenAPI 3.0" of the draft standard "OGC API - Records - Part 1: Core".

This example is a generic OGC API - Records definition that uses path parameters to describe all record collections and all records. The generic OpenAPI definition does not provide any details on the collections or the record content. This information is only available from accessing the record collection resources.

There is another example that specifies each collection explicitly.

## Capabilities

essential characteristics of this API

## landing page

The landing page provides links to the API definition, the conformance statements and to the record collections in this dataset.

##### Authorizations:

openIdConnect

### Responses

Production server

https://example.org/data/

Development server

https://example.org/data-dev/

### Response samples

- 200
- 406
- 4XX
- 5XX

Content type
application/json
`
{

- "title": "string",
- "description": "string",
- "links":
  [
  - {
    - "rel": "string",
    - "type": "string",
    - "hreflang": "string",
    - "title": "string",
    - "length": 0,
    - "created": "2019-08-24T14:15:22Z",
    - "updated": "2019-08-24T14:15:22Z",
    - "href": "http://example.com"
    }
  ],
- "linkTemplates":
  [
  - {
    - "rel": "string",
    - "type": "string",
    - "hreflang": "string",
    - "title": "string",
    - "length": 0,
    - "created": "2019-08-24T14:15:22Z",
    - "updated": "2019-08-24T14:15:22Z",
    - "uriTemplate": "string",
    - "varBase": "http://example.com",
    - "variables": { }
    }
  ]

}`

## Conformance

list of conformance classes implemented by this API

## information about specifications that this API conforms to

A list of all conformance classes specified in a standard that the server conforms to.

##### Authorizations:

openIdConnect

### Responses

Production server

https://example.org/data/conformance

Development server

https://example.org/data-dev/conformance

### Response samples

- 200
- 406
- 4XX
- 5XX

Content type
application/json
`
{

- "conformsTo":
  [
  - "string"
  ]

}`

## Collections

list of catalogs offered by this API

## the record collections

Fetch list of catalogs offered by this API

##### Authorizations:

openIdConnect

### Responses

Production server

https://example.org/data/collections

Development server

https://example.org/data-dev/collections

### Response samples

- 200
- 406
- 4XX
- 5XX

Content type
application/json
`
{

- "links":
  [
  - {
    - "rel": "string",
    - "type": "string",
    - "hreflang": "string",
    - "title": "string",
    - "length": 0,
    - "created": "2019-08-24T14:15:22Z",
    - "updated": "2019-08-24T14:15:22Z",
    - "href": "http://example.com"
    }
  ],
- "collections":
  [
  - {
    - "id": "string",
    - "title": "string",
    - "description": "string",
    - "links":
      [
      - {
        - "rel": "string",
        - "type": "string",
        - "hreflang": "string",
        - "title": "string",
        - "length": 0,
        - "created": "2019-08-24T14:15:22Z",
        - "updated": "2019-08-24T14:15:22Z",
        - "href": "http://example.com"
        }
      ],
    - "extent":
      {
      - "spatial":
        {
        - "bbox":
          [
          - [
            - 0
            ]
          ],
        - "crs": "http://www.opengis.net/def/crs/OGC/1.3/CRS84"
        },
      - "temporal":
        {
        - "interval":
          [
          - [
            - "2019-08-24T14:15:22Z",
            - "2019-08-24T14:15:22Z"
            ]
          ],
        - "trs": "http://www.opengis.net/def/uom/ISO-8601/0/Gregorian"
        }
      },
    - "itemType": "record",
    - "crs":
      [
      - "http://www.opengis.net/def/crs/OGC/1.3/CRS84"
      ],
    - "created": "2019-08-24T14:15:22Z",
    - "updated": "2019-08-24T14:15:22Z",
    - "type": "Collection",
    - "keywords":
      [
      - "string"
      ],
    - "themes":
      [
      - {
        - "concepts":
          [
          - {
            - "id": "string",
            - "title": "string",
            - "description": "string",
            - "url": "http://example.com"
            }
          ],
        - "scheme": "string"
        }
      ],
    - "language":
      {
      - "code": "string",
      - "name": "string",
      - "alternate": "string",
      - "dir": "ltr"
      },
    - "languages":
      [
      - {
        - "code": "string",
        - "name": "string",
        - "alternate": "string",
        - "dir": "ltr"
        }
      ],
    - "resourceLanguages":
      [
      - {
        - "code": "string",
        - "name": "string",
        - "alternate": "string",
        - "dir": "ltr"
        }
      ],
    - "externalIds":
      [
      - {
        - "scheme": "string",
        - "value": "string"
        }
      ],
    - "formats":
      [
      - {
        - "name": "string",
        - "mediaType": "string"
        }
      ],
    - "contacts":
      [
      - {
        - "identifier": "string",
        - "name": "string",
        - "position": "string",
        - "organization": "string",
        - "logo":
          {
          - "rel": "icon",
          - "type": "string",
          - "hreflang": "string",
          - "title": "string",
          - "length": 0,
          - "created": "2019-08-24T14:15:22Z",
          - "updated": "2019-08-24T14:15:22Z",
          - "href": "http://example.com"
          },
        - "phones":
          [
          - {
            - "value": "string",
            - "roles":
              [
              - "string"
              ]
            }
          ],
        - "emails":
          [
          - {
            - "value": "user@example.com",
            - "roles":
              [
              - "string"
              ]
            }
          ],
        - "addresses":
          [
          - {
            - "deliveryPoint":
              [
              - "string"
              ],
            - "city": "string",
            - "administrativeArea": "string",
            - "postalCode": "string",
            - "country": "string",
            - "roles":
              [
              - "string"
              ]
            }
          ],
        - "links":
          [
          - {
            - "rel": "string",
            - "type": "string",
            - "hreflang": "string",
            - "title": "string",
            - "length": 0,
            - "created": "2019-08-24T14:15:22Z",
            - "updated": "2019-08-24T14:15:22Z",
            - "href": "http://example.com"
            }
          ],
        - "hoursOfService": "string",
        - "contactInstructions": "string",
        - "roles":
          [
          - "string"
          ]
        }
      ],
    - "license": "string",
    - "rights": "string",
    - "conformsTo":
      [
      - "string"
      ],
    - "recordsArrayName": "records",
    - "records":
      [
      - {
        - "id": "string",
        - "type": "Feature",
        - "time": { },
        - "geometry": { },
        - "conformsTo":
          [
          - "string"
          ],
        - "properties":
          {
          - "created": "2019-08-24T14:15:22Z",
          - "updated": "2019-08-24T14:15:22Z",
          - "type": "string",
          - "title": "string",
          - "description": "string",
          - "keywords":
            [
            - "string"
            ],
          - "themes":
            [
            - {
              - "concepts":
                [
                - {
                  - "id": null,
                  - "title": null,
                  - "description": null,
                  - "url": null
                  }
                ],
              - "scheme": "string"
              }
            ],
          - "language":
            {
            - "code": "string",
            - "name": "string",
            - "alternate": "string",
            - "dir": "ltr"
            },
          - "languages":
            [
            - {
              - "code": "string",
              - "name": "string",
              - "alternate": "string",
              - "dir": "ltr"
              }
            ],
          - "resourceLanguages":
            [
            - {
              - "code": "string",
              - "name": "string",
              - "alternate": "string",
              - "dir": "ltr"
              }
            ],
          - "externalIds":
            [
            - {
              - "scheme": "string",
              - "value": "string"
              }
            ],
          - "formats":
            [
            - {
              - "name": "string",
              - "mediaType": "string"
              }
            ],
          - "contacts":
            [
            - {
              - "identifier": "string",
              - "name": "string",
              - "position": "string",
              - "organization": "string",
              - "logo":
                {
                - "rel": "icon",
                - "type": "string",
                - "hreflang": "string",
                - "title": "string",
                - "length": 0,
                - "created": "2019-08-24T14:15:22Z",
                - "updated": "2019-08-24T14:15:22Z",
                - "href": "http://example.com"
                },
              - "phones":
                [
                - {
                  - "value": null,
                  - "roles": null
                  }
                ],
              - "emails":
                [
                - {
                  - "value": null,
                  - "roles": null
                  }
                ],
              - "addresses":
                [
                - {
                  - "deliveryPoint": [ ],
                  - "city": null,
                  - "administrativeArea": null,
                  - "postalCode": null,
                  - "country": null,
                  - "roles": null
                  }
                ],
              - "links":
                [
                - {
                  - "rel": null,
                  - "type": null,
                  - "hreflang": null,
                  - "title": null,
                  - "length": null,
                  - "created": null,
                  - "updated": null,
                  - "href": null
                  }
                ],
              - "hoursOfService": "string",
              - "contactInstructions": "string",
              - "roles":
                [
                - "string"
                ]
              }
            ],
          - "license": "string",
          - "rights": "string"
          },
        - "links":
          [
          - {
            - "rel": "string",
            - "type": "string",
            - "hreflang": "string",
            - "title": "string",
            - "length": 0,
            - "created": "2019-08-24T14:15:22Z",
            - "updated": "2019-08-24T14:15:22Z",
            - "href": "http://example.com"
            }
          ],
        - "linkTemplates":
          [
          - {
            - "rel": "string",
            - "type": "string",
            - "hreflang": "string",
            - "title": "string",
            - "length": 0,
            - "created": "2019-08-24T14:15:22Z",
            - "updated": "2019-08-24T14:15:22Z",
            - "uriTemplate": "string",
            - "varBase": "http://example.com",
            - "variables": { }
            }
          ]
        }
      ],
    - "linkTemplates":
      [
      - {
        - "rel": "string",
        - "type": "string",
        - "hreflang": "string",
        - "title": "string",
        - "length": 0,
        - "created": "2019-08-24T14:15:22Z",
        - "updated": "2019-08-24T14:15:22Z",
        - "uriTemplate": "string",
        - "varBase": "http://example.com",
        - "variables": { }
        }
      ],
    - "schemes":
      [
      - {
        - "scheme-id": "string",
        - "namespace": "string",
        - "resolver": { }
        }
      ]
    }
  ],
- "linkTemplates":
  [
  - {
    - "rel": "string",
    - "type": "string",
    - "hreflang": "string",
    - "title": "string",
    - "length": 0,
    - "created": "2019-08-24T14:15:22Z",
    - "updated": "2019-08-24T14:15:22Z",
    - "uriTemplate": "string",
    - "varBase": "http://example.com",
    - "variables": { }
    }
  ]

}`

## Collection

description of a catalog offered by this API

## describe the record collection with id `catalogId`

Fetch a detailed description of a catalog or collection of records with id `catalogId`.

##### Authorizations:

openIdConnect

##### path Parameters

catalogId required | string

### Responses

Production server

https://example.org/data/collections/{catalogId}

Development server

https://example.org/data-dev/collections/{catalogId}

### Response samples

- 200
- 404
- 406
- 4XX
- 5XX

Content type
application/json
`
{

- "id": "string",
- "title": "string",
- "description": "string",
- "links":
  [
  - {
    - "rel": "string",
    - "type": "string",
    - "hreflang": "string",
    - "title": "string",
    - "length": 0,
    - "created": "2019-08-24T14:15:22Z",
    - "updated": "2019-08-24T14:15:22Z",
    - "href": "http://example.com"
    }
  ],
- "extent":
  {
  - "spatial":
    {
    - "bbox":
      [
      - [
        - 0
        ]
      ],
    - "crs": "http://www.opengis.net/def/crs/OGC/1.3/CRS84"
    },
  - "temporal":
    {
    - "interval":
      [
      - [
        - "2019-08-24T14:15:22Z",
        - "2019-08-24T14:15:22Z"
        ]
      ],
    - "trs": "http://www.opengis.net/def/uom/ISO-8601/0/Gregorian"
    }
  },
- "itemType": "record",
- "crs":
  [
  - "http://www.opengis.net/def/crs/OGC/1.3/CRS84"
  ],
- "created": "2019-08-24T14:15:22Z",
- "updated": "2019-08-24T14:15:22Z",
- "type": "Collection",
- "keywords":
  [
  - "string"
  ],
- "themes":
  [
  - {
    - "concepts":
      [
      - {
        - "id": "string",
        - "title": "string",
        - "description": "string",
        - "url": "http://example.com"
        }
      ],
    - "scheme": "string"
    }
  ],
- "language":
  {
  - "code": "string",
  - "name": "string",
  - "alternate": "string",
  - "dir": "ltr"
  },
- "languages":
  [
  - {
    - "code": "string",
    - "name": "string",
    - "alternate": "string",
    - "dir": "ltr"
    }
  ],
- "resourceLanguages":
  [
  - {
    - "code": "string",
    - "name": "string",
    - "alternate": "string",
    - "dir": "ltr"
    }
  ],
- "externalIds":
  [
  - {
    - "scheme": "string",
    - "value": "string"
    }
  ],
- "formats":
  [
  - {
    - "name": "string",
    - "mediaType": "string"
    }
  ],
- "contacts":
  [
  - {
    - "identifier": "string",
    - "name": "string",
    - "position": "string",
    - "organization": "string",
    - "logo":
      {
      - "rel": "icon",
      - "type": "string",
      - "hreflang": "string",
      - "title": "string",
      - "length": 0,
      - "created": "2019-08-24T14:15:22Z",
      - "updated": "2019-08-24T14:15:22Z",
      - "href": "http://example.com"
      },
    - "phones":
      [
      - {
        - "value": "string",
        - "roles":
          [
          - "string"
          ]
        }
      ],
    - "emails":
      [
      - {
        - "value": "user@example.com",
        - "roles":
          [
          - "string"
          ]
        }
      ],
    - "addresses":
      [
      - {
        - "deliveryPoint":
          [
          - "string"
          ],
        - "city": "string",
        - "administrativeArea": "string",
        - "postalCode": "string",
        - "country": "string",
        - "roles":
          [
          - "string"
          ]
        }
      ],
    - "links":
      [
      - {
        - "rel": "string",
        - "type": "string",
        - "hreflang": "string",
        - "title": "string",
        - "length": 0,
        - "created": "2019-08-24T14:15:22Z",
        - "updated": "2019-08-24T14:15:22Z",
        - "href": "http://example.com"
        }
      ],
    - "hoursOfService": "string",
    - "contactInstructions": "string",
    - "roles":
      [
      - "string"
      ]
    }
  ],
- "license": "string",
- "rights": "string",
- "conformsTo":
  [
  - "string"
  ],
- "recordsArrayName": "records",
- "records":
  [
  - {
    - "id": "string",
    - "type": "Feature",
    - "time": { },
    - "geometry": { },
    - "conformsTo":
      [
      - "string"
      ],
    - "properties":
      {
      - "created": "2019-08-24T14:15:22Z",
      - "updated": "2019-08-24T14:15:22Z",
      - "type": "string",
      - "title": "string",
      - "description": "string",
      - "keywords":
        [
        - "string"
        ],
      - "themes":
        [
        - {
          - "concepts":
            [
            - {
              - "id": "string",
              - "title": "string",
              - "description": "string",
              - "url": "http://example.com"
              }
            ],
          - "scheme": "string"
          }
        ],
      - "language":
        {
        - "code": "string",
        - "name": "string",
        - "alternate": "string",
        - "dir": "ltr"
        },
      - "languages":
        [
        - {
          - "code": "string",
          - "name": "string",
          - "alternate": "string",
          - "dir": "ltr"
          }
        ],
      - "resourceLanguages":
        [
        - {
          - "code": "string",
          - "name": "string",
          - "alternate": "string",
          - "dir": "ltr"
          }
        ],
      - "externalIds":
        [
        - {
          - "scheme": "string",
          - "value": "string"
          }
        ],
      - "formats":
        [
        - {
          - "name": "string",
          - "mediaType": "string"
          }
        ],
      - "contacts":
        [
        - {
          - "identifier": "string",
          - "name": "string",
          - "position": "string",
          - "organization": "string",
          - "logo":
            {
            - "rel": "icon",
            - "type": "string",
            - "hreflang": "string",
            - "title": "string",
            - "length": 0,
            - "created": "2019-08-24T14:15:22Z",
            - "updated": "2019-08-24T14:15:22Z",
            - "href": "http://example.com"
            },
          - "phones":
            [
            - {
              - "value": "string",
              - "roles":
                [
                - "string"
                ]
              }
            ],
          - "emails":
            [
            - {
              - "value": "user@example.com",
              - "roles":
                [
                - "string"
                ]
              }
            ],
          - "addresses":
            [
            - {
              - "deliveryPoint":
                [
                - "string"
                ],
              - "city": "string",
              - "administrativeArea": "string",
              - "postalCode": "string",
              - "country": "string",
              - "roles":
                [
                - "string"
                ]
              }
            ],
          - "links":
            [
            - {
              - "rel": "string",
              - "type": "string",
              - "hreflang": "string",
              - "title": "string",
              - "length": 0,
              - "created": "2019-08-24T14:15:22Z",
              - "updated": "2019-08-24T14:15:22Z",
              - "href": "http://example.com"
              }
            ],
          - "hoursOfService": "string",
          - "contactInstructions": "string",
          - "roles":
            [
            - "string"
            ]
          }
        ],
      - "license": "string",
      - "rights": "string"
      },
    - "links":
      [
      - {
        - "rel": "string",
        - "type": "string",
        - "hreflang": "string",
        - "title": "string",
        - "length": 0,
        - "created": "2019-08-24T14:15:22Z",
        - "updated": "2019-08-24T14:15:22Z",
        - "href": "http://example.com"
        }
      ],
    - "linkTemplates":
      [
      - {
        - "rel": "string",
        - "type": "string",
        - "hreflang": "string",
        - "title": "string",
        - "length": 0,
        - "created": "2019-08-24T14:15:22Z",
        - "updated": "2019-08-24T14:15:22Z",
        - "uriTemplate": "string",
        - "varBase": "http://example.com",
        - "variables": { }
        }
      ]
    }
  ],
- "linkTemplates":
  [
  - {
    - "rel": "string",
    - "type": "string",
    - "hreflang": "string",
    - "title": "string",
    - "length": 0,
    - "created": "2019-08-24T14:15:22Z",
    - "updated": "2019-08-24T14:15:22Z",
    - "uriTemplate": "string",
    - "varBase": "http://example.com",
    - "variables": { }
    }
  ],
- "schemes":
  [
  - {
    - "scheme-id": "string",
    - "namespace": "string",
    - "resolver": { }
    }
  ]

}`

## Sortables

list of record properties by which responses can be sorted

## get the list of sortable properties

Fetch the list of properties which can be used to sort the getRecords response.

##### Authorizations:

openIdConnect

##### path Parameters

catalogId required | string

### Responses

Production server

https://example.org/data/collections/{catalogId}/sortables

Development server

https://example.org/data-dev/collections/{catalogId}/sortables

### Response samples

- 200
- 404
- 406
- 4XX
- 5XX

Content type
application/json
`{ }`

## Records

access to records

## fetch records

Fetch records from the record collection with id `catalogId`.

Every record in a dataset belongs to a collection. A dataset may consist of multiple record collections. A record collection is often a collection of records of a similar type, based on a common schema.

Use content negotiation to request HTML or GeoJSON.

##### Authorizations:

openIdConnect

##### path Parameters

catalogId required | string

##### query Parameters

| Array of numbers or Array of numbers
datetime | string
limit | integer [ 1 .. 10000 ] Default: 10
q | Array of strings
type | Array of strings
externalId | Array of strings
ids | Array of strings
sortby | Array of strings non-empty [ items[+|-]?[A-Za-z_].* ]

### Responses

Production server

https://example.org/data/collections/{catalogId}/items

Development server

https://example.org/data-dev/collections/{catalogId}/items

### Response samples

- 200
- 404
- 406
- 4XX
- 5XX

Content type
application/geo+json
`
{

- "type": "FeatureCollection",
- "features":
  [
  - {
    - "type": "Feature",
    - "geometry":
      {
      - "type": "Point",
      - "coordinates":
        [
        - 0,
        - 0
        ]
      },
    - "properties":
      {
      - "created": "2019-08-24T14:15:22Z",
      - "updated": "2019-08-24T14:15:22Z",
      - "type": "string",
      - "title": "string",
      - "description": "string",
      - "keywords":
        [
        - "string"
        ],
      - "themes":
        [
        - {
          - "concepts":
            [
            - {
              - "id": "string",
              - "title": "string",
              - "description": "string",
              - "url": "http://example.com"
              }
            ],
          - "scheme": "string"
          }
        ],
      - "language":
        {
        - "code": "string",
        - "name": "string",
        - "alternate": "string",
        - "dir": "ltr"
        },
      - "languages":
        [
        - {
          - "code": "string",
          - "name": "string",
          - "alternate": "string",
          - "dir": "ltr"
          }
        ],
      - "resourceLanguages":
        [
        - {
          - "code": "string",
          - "name": "string",
          - "alternate": "string",
          - "dir": "ltr"
          }
        ],
      - "externalIds":
        [
        - {
          - "scheme": "string",
          - "value": "string"
          }
        ],
      - "formats":
        [
        - {
          - "name": "string",
          - "mediaType": "string"
          }
        ],
      - "contacts":
        [
        - {
          - "identifier": "string",
          - "name": "string",
          - "position": "string",
          - "organization": "string",
          - "logo":
            {
            - "rel": "icon",
            - "type": "string",
            - "hreflang": "string",
            - "title": "string",
            - "length": 0,
            - "created": "2019-08-24T14:15:22Z",
            - "updated": "2019-08-24T14:15:22Z",
            - "href": "http://example.com"
            },
          - "phones":
            [
            - {
              - "value": "string",
              - "roles":
                [
                - "string"
                ]
              }
            ],
          - "emails":
            [
            - {
              - "value": "user@example.com",
              - "roles":
                [
                - "string"
                ]
              }
            ],
          - "addresses":
            [
            - {
              - "deliveryPoint":
                [
                - "string"
                ],
              - "city": "string",
              - "administrativeArea": "string",
              - "postalCode": "string",
              - "country": "string",
              - "roles":
                [
                - "string"
                ]
              }
            ],
          - "links":
            [
            - {
              - "rel": "string",
              - "type": "string",
              - "hreflang": "string",
              - "title": "string",
              - "length": 0,
              - "created": "2019-08-24T14:15:22Z",
              - "updated": "2019-08-24T14:15:22Z",
              - "href": "http://example.com"
              }
            ],
          - "hoursOfService": "string",
          - "contactInstructions": "string",
          - "roles":
            [
            - "string"
            ]
          }
        ],
      - "license": "string",
      - "rights": "string"
      },
    - "id": "string",
    - "links":
      [
      - {
        - "rel": "string",
        - "type": "string",
        - "hreflang": "string",
        - "title": "string",
        - "length": 0,
        - "created": "2019-08-24T14:15:22Z",
        - "updated": "2019-08-24T14:15:22Z",
        - "href": "http://example.com"
        }
      ],
    - "linkTemplates":
      [
      - {
        - "rel": "string",
        - "type": "string",
        - "hreflang": "string",
        - "title": "string",
        - "length": 0,
        - "created": "2019-08-24T14:15:22Z",
        - "updated": "2019-08-24T14:15:22Z",
        - "uriTemplate": "string",
        - "varBase": "http://example.com",
        - "variables": { }
        }
      ],
    - "time": { },
    - "conformsTo":
      [
      - "string"
      ]
    }
  ],
- "links":
  [
  - {
    - "rel": "string",
    - "type": "string",
    - "hreflang": "string",
    - "title": "string",
    - "length": 0,
    - "created": "2019-08-24T14:15:22Z",
    - "updated": "2019-08-24T14:15:22Z",
    - "href": "http://example.com"
    }
  ],
- "linkTemplates":
  [
  - {
    - "rel": "string",
    - "type": "string",
    - "hreflang": "string",
    - "title": "string",
    - "length": 0,
    - "created": "2019-08-24T14:15:22Z",
    - "updated": "2019-08-24T14:15:22Z",
    - "uriTemplate": "string",
    - "varBase": "http://example.com",
    - "variables": { }
    }
  ],
- "timeStamp": "2019-08-24T14:15:22Z",
- "numberMatched": 0,
- "numberReturned": 0

}`

## Record

access to a single record

## fetch a single record

Fetch the record with id `recordId` from the record collection with id `catalogId`.

Use content negotiation to request HTML or GeoJSON.

##### Authorizations:

openIdConnect

##### path Parameters

catalogId required | string
recordId required | string

### Responses

Production server

https://example.org/data/collections/{catalogId}/items/{recordId}

Development server

https://example.org/data-dev/collections/{catalogId}/items/{recordId}

### Response samples

- 200
- 404
- 406
- 4XX
- 5XX

Content type
application/geo+json
`
{

- "id": "string",
- "type": "Feature",
- "time": { },
- "geometry": { },
- "conformsTo":
  [
  - "string"
  ],
- "properties":
  {
  - "created": "2019-08-24T14:15:22Z",
  - "updated": "2019-08-24T14:15:22Z",
  - "type": "string",
  - "title": "string",
  - "description": "string",
  - "keywords":
    [
    - "string"
    ],
  - "themes":
    [
    - {
      - "concepts":
        [
        - {
          - "id": "string",
          - "title": "string",
          - "description": "string",
          - "url": "http://example.com"
          }
        ],
      - "scheme": "string"
      }
    ],
  - "language":
    {
    - "code": "string",
    - "name": "string",
    - "alternate": "string",
    - "dir": "ltr"
    },
  - "languages":
    [
    - {
      - "code": "string",
      - "name": "string",
      - "alternate": "string",
      - "dir": "ltr"
      }
    ],
  - "resourceLanguages":
    [
    - {
      - "code": "string",
      - "name": "string",
      - "alternate": "string",
      - "dir": "ltr"
      }
    ],
  - "externalIds":
    [
    - {
      - "scheme": "string",
      - "value": "string"
      }
    ],
  - "formats":
    [
    - {
      - "name": "string",
      - "mediaType": "string"
      }
    ],
  - "contacts":
    [
    - {
      - "identifier": "string",
      - "name": "string",
      - "position": "string",
      - "organization": "string",
      - "logo":
        {
        - "rel": "icon",
        - "type": "string",
        - "hreflang": "string",
        - "title": "string",
        - "length": 0,
        - "created": "2019-08-24T14:15:22Z",
        - "updated": "2019-08-24T14:15:22Z",
        - "href": "http://example.com"
        },
      - "phones":
        [
        - {
          - "value": "string",
          - "roles":
            [
            - "string"
            ]
          }
        ],
      - "emails":
        [
        - {
          - "value": "user@example.com",
          - "roles":
            [
            - "string"
            ]
          }
        ],
      - "addresses":
        [
        - {
          - "deliveryPoint":
            [
            - "string"
            ],
          - "city": "string",
          - "administrativeArea": "string",
          - "postalCode": "string",
          - "country": "string",
          - "roles":
            [
            - "string"
            ]
          }
        ],
      - "links":
        [
        - {
          - "rel": "string",
          - "type": "string",
          - "hreflang": "string",
          - "title": "string",
          - "length": 0,
          - "created": "2019-08-24T14:15:22Z",
          - "updated": "2019-08-24T14:15:22Z",
          - "href": "http://example.com"
          }
        ],
      - "hoursOfService": "string",
      - "contactInstructions": "string",
      - "roles":
        [
        - "string"
        ]
      }
    ],
  - "license": "string",
  - "rights": "string"
  },
- "links":
  [
  - {
    - "rel": "string",
    - "type": "string",
    - "hreflang": "string",
    - "title": "string",
    - "length": 0,
    - "created": "2019-08-24T14:15:22Z",
    - "updated": "2019-08-24T14:15:22Z",
    - "href": "http://example.com"
    }
  ],
- "linkTemplates":
  [
  - {
    - "rel": "string",
    - "type": "string",
    - "hreflang": "string",
    - "title": "string",
    - "length": 0,
    - "created": "2019-08-24T14:15:22Z",
    - "updated": "2019-08-24T14:15:22Z",
    - "uriTemplate": "string",
    - "varBase": "http://example.com",
    - "variables": { }
    }
  ]

}`